@@ -1577,6 +1577,7 @@ def scatter09lr6sigma(df, parameter_x, parameter_y, sigma, title):
 
 
 # >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> [to be validated. update:12/28]
+# normality test. input target list is enough
 def normaltest(targetlist):
     import numpy as np
     from scipy import stats
@@ -1599,6 +1600,23 @@ def normaltest(targetlist):
     plt.show()
 
 
+# parallel coordinator plot
+def parallel(df, category, title):
+    import numpy as np
+    import matplotlib.pyplot as plt
+    from pandas.plotting import parallel_coordinates
+
+    df = df
+
+    plt.figure(figsize=(8, 6))
+    parallel_coordinates(df, category, colormap='tab10', alpha=0.8, lw=3)
+
+    plt.xticks(rotation=30)
+    plt.grid(linestyle='-', alpha=0.5)
+    plt.legend(loc='upper left')
+    plt.title(title)
+    plt.show()
+
 
 # show correlation line + error zone. with scatter plot:
 
